;ClipStep.ahk
; Control multiple clipboards using only the keyboard's Ctrl-X-C-V
; 
; Select some text, press Ctrl-C a couple of times to copy it to multiple new clipboards. 
; Now hold down Ctrl and press V repeatedly to step through the clipboards. C steps backwards. 
; When you've got the clipboard you want, release Ctrl to paste. 
; To delete a clipboard, hold down Ctrl, press V followed by X twice to delete, three times to 
; delete all, or once to cancel. Release Ctrl to accept. 
;
;Skrommel @2005
;Modified TWmailrec
; MOD: HOTKEY ^!NumpadMult, or ^!* for Clipseek search  (not used)
; MOD: {F10} to quit Clipsearch
; MOD: [Ctrl]-C to Copy item to Clipboard. Clipstep shows tooltip to indicate clip file created.
; MOD: [Ctrl]-X to Cut  item to Clipboard. Clipstep shows tooltip to indicate clip file created.
; MOD: [Ctrl]-C and [Ctrl]-X, if editing a file, and text is not blocked, Clipstep will attempt 
;      to select current line to copy/cut to clipboard and create the clip file.

; MOD: Search Filter: Right-click Taskbar icon and select "ClipSearch...".
;      Enter a single unquoted string to search within stored clips, 
;      using A-Z,1-9, BUT NO COMMAS. To change the keys, choose ClipSearch in the tray menu.
;      If search successful, Press Ctrl-V to Show clips.
;      To view full selection after Search, Press Alt-Ctrl-V or select "Settings", and "Cancel" 
;      On "Copy" (^C) or "Paste (^V), normal complete selection is restored
; MOD: Ctrl-Alt-V added to Toggle Current (%A_WorkingDir%) & Permanent dir: .\Perm
;   This option only available after ^V pressed
; MOD: Ctrl-Alt-C added to COPY current clip(%A_WorkingDir%) TO: Permanent dir: .\Perm
;   This option only available after ^V pressed, if current dir is default
; MOD: SHOWCLIP (^V) uses Progress for readability and shows Previous & Next clip
;      as well as showing current clip filename, No. of Total clips, and if FILE / Address
; MOD: [Ctrl]-V-C to run the ClipSeek Search program **
; MOD: [Ctrl]-V-X to run the ClipSeek Directory Search program **

Goto, CustomOUT

;===================== Program Customisation =======================
; Specify which [SETTING] TO USE and which directory for specified programs

ProgCheck:

IfWinActive, %iniprog%
{
    IniRead,PrgPreset,%A_ScriptDir%\ClpSrch.ini,clipSettings,PrgPreset
    If PrgPreset = %iniprog%
        Return
    IniRead,WinTitle,%A_ScriptDir%\ClpSrch.ini,%iniprog%,WinTitle
		IfWinNotExist, %WinTitle%
			Return
    IniRead,PrgPreset,%A_ScriptDir%\ClpSrch.ini,%iniprog%,PrgPreset
;   If PrgPreset != %iniprog%
;           Return

;Tooltip = PrgPreset=%PrgPreset%`,iniprog=%iniprog%
;GoSub, Tooltip
    GoSub, PROG_ASSIGN
    Return
}

Return


PROG_ASSIGN:
IniRead,Perm_Nom,%A_ScriptDir%\ClpSrch.ini,%PrgPreset%,perm_Nom
If Perm_Nom = ERROR
    MsgBox, 0,,INI key ERROR: %Perm_Nom% Does not exist under %PrgPreset%", 10
IfNotExist, %A_ScriptDir%%Perm_Nom%
    Perm_Nom=\Perm
IniWrite,%Perm_Nom%,%A_ScriptDir%\ClpSrch.ini,clipSettings,perm_Nom
IniRead,Perm,%A_ScriptDir%\ClpSrch.ini,%PrgPreset%,perm
IniWrite,%Perm%,%A_ScriptDir%\ClpSrch.ini,clipSettings,perm
If perm=0
    perm_cur=
If perm=ERROR
    perm_cur=
If perm != 0
{
	StringTrimLeft, Perm_cur, Perm_Nom, 1
	perm_cur=%perm_cur%\
}

IniWrite,%PrgPreset%,%A_ScriptDir%\ClpSrch.ini,clipSettings,PrgPreset
IniRead,_tmp,%A_ScriptDir%\ClpSrch.ini,%PrgPreset%,recrs
IniWrite,%_tmp%,%A_ScriptDir%\ClpSrch.ini,clipSettings,recrs
IniRead,_tmp,%A_ScriptDir%\ClpSrch.ini,%PrgPreset%,clipshow
IniWrite,%_tmp%,%A_ScriptDir%\ClpSrch.ini,clipSettings,clipshow
; clipstep can preset defaults for clipseek
	IniRead,scantemp,%A_ScriptDir%\ClpSrch.ini,%PrgPreset%,scanPath
	If scantemp = ERROR
		IniRead,scantemp,%A_ScriptDir%\ClpSrch.ini,Settings,scanPath
	If scantemp=ERROR
	{
		scantemp = A_StartMenu|A_StartMenuCommon
		IniWrite,A_StartMenu|A_StartMenuCommon,%A_ScriptDir%\ClpSrch.ini,Settings,scanPath
	}
	Scan_S_R=

Scan_SR:
; Note the order, A_StartMenu exists in string A_StartMenuCommon
	IfInString, scantemp, A_StartMenuCommon
		StringReplace, scantemp, scantemp, A_StartMenuCommon, %A_StartMenuCommon%, All
	IfInString, scantemp, A_StartMenu
		StringReplace, scantemp, scantemp, A_StartMenu, %A_StartMenu%, All
	IfInString, scantemp, A_StartMenu`%Common
		StringReplace, scantemp, scantemp, `%A_StartMenu`%Common, A_StartMenuCommon, All
	IfInString, scantemp, A_MyDocuments
		StringReplace, scantemp, scantemp, A_MyDocuments, %A_MyDocuments%, All
	IfInString, scantemp, ComSpec
		StringReplace, scantemp, scantemp, ComSpec, %ComSpec%, All
	IfInString, scantemp, A_ProgramFiles
		StringReplace, scantemp, scantemp, A_ProgramFiles, %A_ProgramFiles%, All
	IfInString, scantemp, A_WinDir
		StringReplace, scantemp, scantemp, A_WinDir, %A_WinDir%, All
	IfInString, scantemp, A_DesktopCommon
		StringReplace, scantemp, scantemp, A_DesktopCommon, %A_DesktopCommon%, All
	IfInString, scantemp, A_Desktop
		StringReplace, scantemp, scantemp, A_Desktop, %A_Desktop%, All
	IfInString, scantemp, A_Desktop`%Common
		StringReplace, scantemp, scantemp, `%A_Desktop`%Common, A_DesktopCommon, All

;	StringTrimRight, scantemp, scantemp, 1
	StringReplace, scantemp, scantemp, ||, |, All
	If Scan_S_R
		Return
	scan0Path=

	IniWrite,%scantemp%,%A_ScriptDir%\ClpSrch.ini,clipSettings,scanPath
;	scanpath = %scantemp%			;Not valid for clipstep
	scanpathPrev = %scantemp%
	scantemp=

	IniRead,scantemp,%A_ScriptDir%\ClpSrch.ini,%PrgPreset%,ScanADDPath
	If scantemp = ERROR
	{
		IniDelete,%A_ScriptDir%\ClpSrch.ini,clipSettings,ScanADDPath
		scantemp=
		ScanADDPath=
	}
	If scantemp
	{
		If scantemp in A_Desktop,A_ProgramFiles,A_WinDir,A_MyDocuments,A_StartMenu
		{
			Scan_S_R := 1
			GoSub, Scan_SR
			Scan_S_R=
		}
		ScanADDPath = %scantemp%
		IniWrite,%ScanADDPath%,%A_ScriptDir%\ClpSrch.ini,clipSettings,ScanADDPath
		scantemp=
	}

	if PrgPreset
		IniRead,scantemp,%A_ScriptDir%\ClpSrch.ini,%PrgPreset%,scanAltPath
;	Else
;		IniRead,scantemp,%A_ScriptDir%\ClpSrch.ini,clipSettings,scanAltPath
	If scantemp = ERROR
	{
		IniDelete,%A_ScriptDir%\ClpSrch.ini,clipSettings,scanAltPath
		scantemp=
		scanAltPath=
	}
	If scantemp
	{
		If scantemp in A_Desktop,A_ProgramFiles,A_WinDir,A_MyDocuments,A_StartMenu
		{
			Scan_S_R := 1
			GoSub, Scan_SR
			Scan_S_R=
		}
		scanAltPath = %scantemp%
		IniWrite,%scanAltPath%,%A_ScriptDir%\ClpSrch.ini,clipSettings,scanAltPath
		scantemp=
	}

Return
; ONLY NEEDED IN CLIPSEEK
	IniRead,VwrPane,%A_ScriptDir%\ClpSrch.ini,%PrgPreset%,VwrPane
	If VwrPane=ERROR
	{
		NoVwrPane=1
		VwrPane=
	}
	If (VwrPane = 1) or (VwrPane = 0)
		NoVwrPane=0
	If VwrPane=0
		VwrPane=

	IniRead,StrtShowAll,%A_ScriptDir%\ClpSrch.ini,%PrgPreset%,StrtShowAll
	If StrtShowAll != 0
		StrtShowAll = 1
	IniRead,DirLstExc,%A_ScriptDir%\ClpSrch.ini,%PrgPreset%,DirLstExc
	If DirLstExc = ERROR
		DirLstExc=
;	If DirLstExc
;	IniWrite,%DirLstExc%,%A_ScriptDir%\ClpSrch.ini,clipSettings,DirLstExc
	IniRead,DirExtInc,%A_ScriptDir%\ClpSrch.ini,%PrgPreset%,DirExtInc
	If DirExtInc = ERROR
		DirExtInc=
;	If DirExtInc
;	IniWrite,%DirExtInc%,%A_ScriptDir%\ClpSrch.ini,clipSettings,DirExtInc
	IniRead,DirExtExc,%A_ScriptDir%\ClpSrch.ini,%PrgPreset%,DirExtExc
	If DirExtExc = ERROR
		DirExtExc=
;	If DirExtExc
;	IniWrite,%DirExtExc%,%A_ScriptDir%\ClpSrch.ini,clipSettings,DirExtExc

	IniRead,PrgExecB,%A_ScriptDir%\ClpSrch.ini,%PrgPreset%,PrgExecB
	If PrgExecB = ERROR
		PrgExecB =
	IniRead,PrgExtB,%A_ScriptDir%\ClpSrch.ini,%PrgPreset%,PrgExtB
	If PrgExtB = ERROR
		PrgExtB =

	IniRead,progrunkey,%A_ScriptDir%\ClpSrch.ini,%PrgPreset%,progrunkey
	If progrunkey = ERROR
		progrunkey =
	IniRead,AutprogDirkey,%A_ScriptDir%\ClpSrch.ini,%PrgPreset%,AutprogDirkey
	If AutprogDirkey = ERROR
		AutprogDirkey =

Return

;...................... END OF Program Customisation ................


NONCustom:

    IniWrite,0,%A_ScriptDir%\ClpSrch.ini,clipSettings,PrgPreset
    PrgPreset = 0
    IniWrite,\Perm,%A_ScriptDir%\ClpSrch.ini,clipSettings,perm_Nom
    IniWrite,0,%A_ScriptDir%\ClpSrch.ini,clipSettings,perm
    IniWrite,1,%A_ScriptDir%\ClpSrch.ini,clipSettings,recrs
    IniWrite,1,%A_ScriptDir%\ClpSrch.ini,clipSettings,clipshow
    IniDelete, %A_ScriptDir%\ClpSrch.ini,clipSettings,scanPath
	IniRead,scantemp,%A_ScriptDir%\ClpSrch.ini,Settings,scanPath
	If scantemp=ERROR
	{
		scantemp = A_StartMenu|A_StartMenuCommon
		IniWrite,A_StartMenu|A_StartMenuCommon,%A_ScriptDir%\ClpSrch.ini,Settings,scanPath
	}
	IfInString, scantemp, A_StartMenuCommon
		StringReplace, scantemp, scantemp, A_StartMenuCommon, %A_StartMenuCommon%, All
	IfInString, scantemp, A_StartMenu
		StringReplace, scantemp, scantemp, A_StartMenu, %A_StartMenu%, All
	IfInString, scantemp, A_StartMenu`%Common
		StringReplace, scantemp, scantemp, `%A_StartMenu`%Common, A_StartMenuCommon, All
	IfInString, scantemp, A_MyDocuments
		StringReplace, scantemp, scantemp, A_MyDocuments, %A_MyDocuments%, All
	IfInString, scantemp, ComSpec
		StringReplace, scantemp, scantemp, ComSpec, %ComSpec%, All
	IfInString, scantemp, A_ProgramFiles
		StringReplace, scantemp, scantemp, A_ProgramFiles, %A_ProgramFiles%, All
	IfInString, scantemp, A_WinDir
		StringReplace, scantemp, scantemp, A_WinDir, %A_WinDir%, All
	IfInString, scantemp, A_DesktopCommon
		StringReplace, scantemp, scantemp, A_DesktopCommon, %A_DesktopCommon%, All
	IfInString, scantemp, A_Desktop
		StringReplace, scantemp, scantemp, A_Desktop, %A_Desktop%, All
	IfInString, scantemp, A_Desktop`%Common
		StringReplace, scantemp, scantemp, `%A_Desktop`%Common, A_DesktopCommon, All
;	StringTrimRight, scantemp, scantemp, 1
	StringReplace, scantemp, scantemp, ||, |, All
	IniWrite,%scantemp%,%A_ScriptDir%\ClpSrch.ini,clipSettings,scanPath
;	scanpath = %scantemp%			;Not valid for clipstep
	scantemp=
	IniDelete,%A_ScriptDir%\ClpSrch.ini,clipSettings,ScanADDPath
	IniDelete,%A_ScriptDir%\ClpSrch.ini,clipSettings,scanAltPath
;    IniDelete, %A_ScriptDir%\ClpSrch.ini,clipSettings,scanPath

    Perm_cur=
    scanAltPath=
    ScanADDPath=
    Return

INICheck:
; Check program aginst Defaults

;prg_width := (A_ScreenWidth * 0.48)
;prg_width := (A_ScreenWidth * 0.60) & Font_SizeT =8
	If A_ScreenWidth < 810
	{
	    Font_SizeT =10 ; (default = 10)
	    Font_SizeH =8  ; (default = 08)
		prg_width := (A_ScreenWidth * 0.75)
		prg_height := (A_ScreenHeight * 0.67)
	}
	Else
	If A_ScreenWidth = 1024
	{
	    Font_SizeT =12 ; (default = 12)
	    Font_SizeH =10 ; (default = 10)
		prg_width := (A_ScreenWidth * 0.70)
		prg_height := (A_ScreenHeight * 0.60)
	}
	Else
	If A_ScreenWidth = 1152
	{
	    Font_SizeT =13 ; (default = 13)
	    Font_SizeH =11 ; (default = 11)
		prg_width := (A_ScreenWidth * 0.65)
		prg_height := (A_ScreenHeight * 0.55)
	}
	If (A_ScreenWidth > 1250)
	{
	    Font_SizeT =12 ; (default = 12)
	    Font_SizeH =11 ; (default = 11)
		prg_width := (A_ScreenWidth * 0.55)
		prg_height := (A_ScreenHeight * 0.50)
	}



Loopcount = 1
SetTitleMatchMode, 2  ; In case it's 3. This setting is in effect only for this thread.
WinGetActiveTitle, ActiveTitle
If ActiveTitle contains clpSeek, clipseek.exe
{
	clpSeek := 1
	Return
}
Else
	clpSeek := 0
If ActiveTitle contains ClpSrch.ini
	Return
If ActiveTitle
	IniWrite,%ActiveTitle%,%A_ScriptDir%\ClpSrch.ini,clipSettings,ActiveTitle
Else
	IniDelete,%A_ScriptDir%\ClpSrch.ini,clipSettings,ActiveTitle
; ; PrgPreset = 0
IniRead,PrgPreset,%A_ScriptDir%\ClpSrch.ini,clipSettings,PrgPreset
If PrgPreset = ERROR
    PrgPreset = 0
If PrgPreset =
    PrgPreset = 0
If PrgPreset = 0
{
	If ActiveTitle = %Null_var%
		Return
    PrgPreset = 0- - - - -
}

;If ActiveTitle contains %PrgPreset%
;	Return
;	;IfWinNotExist, %PrgPreset%
;	;IfWinNotActive, %PrgPreset%
;{
    IniRead,ALLPresetPrg,%A_ScriptDir%\ClpSrch.ini,clipSettings,ALLPresetPrg
	If ALLPresetPrg = ERROR
	{
			GoSub, NONCustom
			Return
	}

	iniprog=
	If ActiveTitle contains %ALLPresetPrg%
    {
        PrgPresetPrev = %PrgPreset%
        Loop, parse, ALLPresetPrg, `,
        {
			If ActiveTitle contains %A_LoopField%
			{
	            iniprog = %A_LoopField%
				StringReplace, SecPresetPrg, ALLPresetPrg, %A_LoopField%, XBypassX,
				If ActiveTitle contains %SecPresetPrg%
				{
			        Loop, parse, SecPresetPrg, `,
					{
						If ActiveTitle contains .%A_LoopField%,.%A_LoopField%],%A_LoopField%]
				            iniprog = %A_LoopField%
					}
				}
				If PrgPreset = %iniprog%
    	            Break
    	        GoSub, ProgCheck
	            If PrgPresetPrev != %PrgPreset%
    	            Break
			}
        }
	}
    Else
    {
        PrgPresetPrev = %PrgPreset%
        Loop, parse, ALLPresetPrg, `,
        {
			IfWinExist, %A_LoopField%
			{
	            iniprog = %A_LoopField%
				StringReplace, SecPresetPrg, ALLPresetPrg, %A_LoopField%, XBypassX,
		          Loop, parse, SecPresetPrg, `,
				  {
					IfWinExist, .%A_LoopField%
			            iniprog = %A_LoopField%
					IfWinExist, .%A_LoopField%]
			            iniprog = %A_LoopField%
					IfWinExist, %A_LoopField%]
			            iniprog = %A_LoopField%
				  }
				If PrgPreset = %iniprog%
				{
					PrgPresetPrev=
					Break
				}
				IniRead,PrgPreset,%A_ScriptDir%\ClpSrch.ini,%iniprog%,PrgPreset
    	        GoSub, PROG_ASSIGN
;		For more than one Preset Program ACTIVE: comment out 2 lines below?
	            If PrgPresetPrev != %PrgPreset%
    	            Break
			}
		}
        If PrgPreset = %PrgPresetPrev%
            GoSub, NONCustom
    }

;}

;				Return
; CHECK IF Activeclip exists

readclip=filearray%activeclip%
readclip:=%readclip%
if Perm_cur
{
	IfExist, %A_ScriptDir%\%Perm_cur%%readclip%.clip*
	Return
}
Else
	IfExist, %A_ScriptDir%\%readclip%.clip*
		Return

;    MsgBox, 0,, %A_ScriptDir%%Perm_cur%\%readclip%.clip* missing, 10
If readclip = 0	
	Return

ReReadclip:

;    numofclips=0
;    activeclip=0
;    filearray1=0
;    Gosub,INDEXCtrlC
numofclips=0
activeclip=1
Gosub,INDEX
activeclip=1

  readclip=filearray%activeclip%
  readclip:=%readclip%
; IniWrite,%readclip%,%A_ScriptDir%\ClpSrch.ini,clipSettings,readclip
Return


CustomOUT:

;**************************
;<--- BEGIN OF PROGRAM --->
;**************************



SetBatchLines,-1
StringCaseSense, Off
numofclips=0
activeclip=1
paste=no
delete=no

IniRead,clpblock,%A_ScriptDir%\ClpSrch.ini,Settings,clpblock
If clpblock != 1
	clpblock = 0

;If clpblock != 1
	Gosub,INDEX
 Gosub,INI
;GoSub INICheck


IniRead,SC_A,%A_ScriptDir%\ClpSrch.ini,Settings,SC_A
If SC_A=ERROR
	SC_A=
If SC_A
  IfNotExist, %SC_A%
  {
	SC_A=
	IniDelete,%A_ScriptDir%\ClpSrch.ini,Settings,SC_A
  }
If SC_A
{
	SplitPath, SC_A,,Dir_SC_A,Ext_SC_A,PrgSC_A
	If Ext_SC_A != lnk
	{
		IfExist, %A_ScriptDir%\!filscrpt\%PrgSC_A%.lnk
			FileDelete, %A_ScriptDir%\!filscrpt\%PrgSC_A%.lnk
		FileCreateShortcut, %SC_A%, %A_ScriptDir%\!filscrpt\%PrgSC_A%.lnk
;		, %Dir_SC_A%
		IniWrite,%A_ScriptDir%\!filscrpt\%PrgSC_A%.lnk,%A_ScriptDir%\ClpSrch.ini,Settings,SC_A
		SC_A = %A_ScriptDir%\!filscrpt\%PrgSC_A%.lnk
		Dir_SC_A=
		Ext_SC_A=
	}
}
IniRead,SC_S,%A_ScriptDir%\ClpSrch.ini,Settings,SC_S
If SC_S=ERROR
	SC_S=
If SC_S
  IfNotExist, %SC_S%
  {
	SC_S=
	IniDelete,%A_ScriptDir%\ClpSrch.ini,Settings,SC_S
  }
If SC_S
{
	SplitPath, SC_S,,Dir_SC_S,Ext_SC_S,PrgSC_S
	If Ext_SC_S != lnk
	{
		IfExist, %A_ScriptDir%\!filscrpt\%PrgSC_S%.lnk
			FileDelete, %A_ScriptDir%\!filscrpt\%PrgSC_S%.lnk
		FileCreateShortcut, %SC_S%, %A_ScriptDir%\!filscrpt\%PrgSC_S%.lnk
;		, %Dir_SC_S%
		IniWrite,%A_ScriptDir%\!filscrpt\%PrgSC_S%.lnk,%A_ScriptDir%\ClpSrch.ini,Settings,SC_S
		SC_S = %A_ScriptDir%\!filscrpt\%PrgSC_S%.lnk
		Dir_SC_S=
		Ext_SC_S=
	}
}
IniRead,SC_D,%A_ScriptDir%\ClpSrch.ini,Settings,SC_D
If SC_D=ERROR
	SC_D=
If SC_D
  IfNotExist, %SC_D%
  {
	SC_D=
	IniDelete,%A_ScriptDir%\ClpSrch.ini,Settings,SC_D
  }
If SC_D
{
	SplitPath, SC_D,,Dir_SC_D,Ext_SC_D,PrgSC_D
	If Ext_SC_D != lnk
	{
		IfExist, %A_ScriptDir%\!filscrpt\%PrgSC_D%.lnk
			FileDelete, %A_ScriptDir%\!filscrpt\%PrgSC_D%.lnk
		FileCreateShortcut, %SC_D%, %A_ScriptDir%\!filscrpt\%PrgSC_D%.lnk
;		, %Dir_SC_D%
		IniWrite,%A_ScriptDir%\!filscrpt\%PrgSC_D%.lnk,%A_ScriptDir%\ClpSrch.ini,Settings,SC_D
		SC_D = %A_ScriptDir%\!filscrpt\%PrgSC_D%.lnk
		Dir_SC_D=
		Ext_SC_D=
	}
}
IniRead,SC_F,%A_ScriptDir%\ClpSrch.ini,Settings,SC_F
If SC_F=ERROR
	SC_F=
If SC_F
  IfNotExist, %SC_F%
  {
	SC_F=
	IniDelete,%A_ScriptDir%\ClpSrch.ini,Settings,SC_F
  }
If SC_F
{
	SplitPath, SC_F,,Dir_SC_F,Ext_SC_F,PrgSC_F
	If Ext_SC_F != lnk
	{
		IfExist, %A_ScriptDir%\!filscrpt\%PrgSC_F%.lnk
			FileDelete, %A_ScriptDir%\!filscrpt\%PrgSC_F%.lnk
		FileCreateShortcut, %SC_F%, %A_ScriptDir%\!filscrpt\%PrgSC_F%.lnk
;		, %Dir_SC_F%
		IniWrite,%A_ScriptDir%\!filscrpt\%PrgSC_F%.lnk,%A_ScriptDir%\ClpSrch.ini,Settings,SC_F
		SC_F = %A_ScriptDir%\!filscrpt\%PrgSC_F%.lnk
		Dir_SC_F=
		Ext_SC_F=
	}
}

Gosub,TRAYMENU

LOOP:
Sleep,100
Loopcount+=20
If Loopcount > 100
    GoSub INICheck

If clpSeek = 1
	Sleep,500

If clpblock
	Goto,LOOP

GetKeyState,state,CTRL
If state=u
{
  clpSeekAct = 0
  If delete=delete
  { 
    readclip=filearray%activeclip%
    readclip:=%readclip%
    Filedelete,%perm_cur%%readclip%.clip*
    IfExist,%perm_cur%%readclip%.clip*.C
	    Filedelete,%perm_cur%%readclip%.clip*.C
    tooltip=Deleting Clip %perm_cur%%readclip% of %numofclips%
    Gosub,TOOLTIP
    Gosub,INDEX
    Gosub,FINDPREV
  }
  Else
  If delete=all
  {
    tooltip=Deleting all %perm_cur%clips
    Gosub,TOOLTIP
;    Filedelete,%perm_cur%*.clip*
    Filedelete,%perm_cur%*.clip
    numofclips=0
    activeclip=0
    filearray1=0
    Gosub,INDEXCtrlC
    activeclip=%numofclips%
  }
  Else    
  If paste=paste
  {
    readclip=filearray%activeclip%
    readclip:=%readclip%
    tooltip=Pasting clip %perm_cur% %readclip%
	If TaskBPaste
	{
		sleep, 200
	    tooltip=Pasting clipboard
	}
    Gosub,TOOLTIPShrt
    Gosub,PASTECLIP
  }
  delete=no
  paste=no
}
;Else
;{
;    KeyIsDown := GetKeyState("LCtrl","P") AND GetKeyState("v","P") AND GetKeyState("c","P")
;    If KeyIsDown
;        GoSub, clipseek
;    KeyIsDown := GetKeyState("LCtrl","P") AND GetKeyState("v","P") AND GetKeyState("x","P")
;    If KeyIsDown
;        GoSub, clseekDir
;}
Goto,LOOP



$^x::
; SplashTextOff
; showflag true indicates ^v (SHOWCLIP) mode, & enables key ^!v 
If clpSeekAct = 1
	Sleep, 500
KeyIsDown := GetKeyState("v","P") AND GetKeyState("LCtrl","P")
If KeyIsDown
    Goto, clseekDirBpA
;Sleep, 500
;KeyIsDown := GetKeyState("v","P") AND GetKeyState("LCtrl","P")
;If KeyIsDown
;    Goto, clseekDirBpA

If clpblock
{
	Send ^x
	Return
}
ClpBp_Cut := GetKeyState("RCtrl","P") AND GetKeyState("x","P")
If ClpBp_Cut
{
	ClpBp_Cut := 0
	Send ^x
	Sleep, 300
	Return
}

IniRead,perm_cur,%A_ScriptDir%\ClpSrch.ini,clipSettings,perm
If perm_cur=0
    perm_cur=
If perm_cur=ERROR
    perm_cur=
If perm_cur=Perm
    Iniread,Perm_cur,%A_ScriptDir%\ClpSrch.ini,clipSettings,perm_Nom
IfNotExist, %A_ScriptDir%%Perm_cur%
    Perm_cur=\Perm
If perm_cur
{
    StringTrimLeft, Perm_cur, Perm_cur, 1
    perm_cur=%perm_cur%\
}

;=numofclips=0
;=activeclip=1
Gosub,INDEX
showflag = %Null_var%
Progress, Off
If paste<>no
{
  If delete=delete
  {
;    ToolTip,Delete all clips
;    SetTimer,TOOLTIPOFF,Off
    tooltip=Delete all clips (Not Comment or ordered type)
    Gosub,TOOLTIP
    delete=all
    paste=yes
    Return
  }
  Else
  If delete=cancel
  {
    If numofclips<1
    {
      tooltip=%perm_cur% - No clip exists
      Gosub,TOOLTIP
      Return
    }
    readclip=filearray%activeclip%
    readclip:=%readclip%
IfExist,%perm_cur%%readclip%.clip0
	FileRead,Clipboard,*c %perm_cur%%readclip%.clip0
IfExist,%perm_cur%%readclip%.clip1
	FileRead,Clipboard,*c %perm_cur%%readclip%.clip1
IfExist,%perm_cur%%readclip%.clip
	FileRead,Clipboard,*c %perm_cur%%readclip%.clip

    StringLeft,clip,Clipboard,100
    tooltip=Delete Clip %perm_cur%%readclip% of %numofclips%`n%clip%
;    SetTimer,TOOLTIPOFF,Off
    Gosub,TOOLTIP
    delete=delete
    paste=yes
    Return
  }
  Else
  {
    tooltip=Cancel
    Gosub,TOOLTIP
    delete=cancel
    paste=yes
;	activeclip=1
    Return
  }
}
If SrchOn
{
   StringReplace, perm_cur, perm_cur, (S)\, , All
   SrchOn=
   numofclips=0
   activeclip=1
   Gosub,INDEX
}

clipBdPrev:=ClipboardAll
clip1:=clipPrev
Clipboard=
Send,^x
ClipWait,1
clip2:=ClipboardAll
If clip2=
{
  Send, {Home}+{Down}^x
  clip2:=ClipboardAll
}
If clip2=
{
  tooltip=%perm_cur% No text selection
  Gosub,TOOLTIP
}
Else
If clip1<>%clip2%
{
  numofclips=0
  activeclip=1
  Gosub,INDEXCtrlC
  Gosub,ADDCLIP
  tooltip=Copying to %perm_cur% %lastclip%.clip
  Gosub,TOOLTIP
  Gosub,INDEX
}
Else
{
  tooltip=%perm_cur% - Same selection
  Gosub,TOOLTIP
}
Clipboard:=clipBdPrev
;clipBdPrev=
clip1=
clip2=
Return


;  $^!NumpadMult::                                  ;;
; SplashTextOff 
; showflag true indicates ^v (SHOWCLIP) mode, & enables key ^!v 
If clpblock
  Goto, clseekDirBpA

If Showflag
  Goto, clseekDirBpA
Else
  Send, ^!{NumpadMult}
Return



$<^>!c::

If clpblock
	Goto, ClipBlockOff
;	Goto, clpblock_TglOFF

Goto, ClipBlockOn

; ** OBS **
; Chk for clpblock Toggle, bypassing Clipstep:
;	clpblock_Tgl := GetKeyState("RCtrl","P") AND GetKeyState("c","P")
clpblock_Tgl := GetKeyState("LCtrl","P") AND GetKeyState("RAlt","P")
If clpblock_Tgl
{
	clpblock_Tgl := 0
	clpblock := 1

}
Return


clpblock_TglOFF:
; ** OBS **
; Chk for clpblock Toggle, bypassing Clipstep:
clpblock_Tgl := GetKeyState("LCtrl","P") AND GetKeyState("RAlt","P")
If clpblock_Tgl
{
	clpblock_Tgl := 0
	clpblock := 0
}
Return

$^c::
; SplashTextOff 
; showflag true indicates ^v (SHOWCLIP) mode, & enables key ^!v 
If clpblock
{
	Send ^c
	Return
}
ClpBp_Copy := GetKeyState("RCtrl","P") AND GetKeyState("c","P")
If ClpBp_Copy
{
	ClpBp_Copy := 0
	Send ^c
	Sleep, 300
	ToolTip = Copied to SYSTEM ClipBoard
	GoSub, ToolTip
	Return
}


If clpSeekAct = 1
	Sleep, 500
KeyIsDown := GetKeyState("v","P")
If KeyIsDown
    Goto, clipseek
;KeyIsDown := GetKeyState("v","P")
;If KeyIsDown
;    Goto, clipseek
    
; if (perm_cur = "(S)\") and (showflag = 1)
if (SrchOn = 1) and (showflag = 1)
	Goto, SearchshowCOn
; see 		Goto, SearchmodeOn

IniRead,perm_cur,%A_ScriptDir%\ClpSrch.ini,clipSettings,perm
If perm_cur=0
    perm_cur=
If perm_cur=ERROR
    perm_cur=
If perm_cur=Perm
    Iniread,Perm_cur,%A_ScriptDir%\ClpSrch.ini,clipSettings,perm_Nom
IfNotExist, %A_ScriptDir%%Perm_cur%
    Perm_cur=\Perm
If perm_cur
{
    StringTrimLeft, Perm_cur, Perm_cur, 1
    perm_cur=%perm_cur%\
}

SearchshowCOn:
;=numofclips=0
;=activeclip=1
Gosub,INDEX
If paste<>no
{
  If numofclips<1
  {
    tooltip=%perm_cur% - No clip exists
    Gosub,TOOLTIP
    delete=no
    paste=yes
    showflag = %Null_var%
    Progress, Off
    Return
  }
  Gosub,FINDPREV
  Gosub,SHOWCLIP
  delete=no
  paste=paste
  Return
}

showflag = %Null_var%
Progress, Off
If SrchOn
{
   StringReplace, perm_cur, perm_cur, (S)\, , All
   SrchOn=
   numofclips=0
   activeclip=1
   Gosub,INDEXCtrlC
}


clipBdPrev:=ClipboardAll
clip1:=clipPrev
Clipboard=
Send,^c
ClipWait,1
clip2:=ClipboardAll
If clip2=
{
  Send, {Home}+{Down}^c{Up}
  clip2:=ClipboardAll
}
If clip2=
{
  tooltip=%perm_cur% No text selection
  Gosub,TOOLTIP
}
Else
If clip1<>%clip2%
{
	numofclips=0
	activeclip=1
	Gosub,INDEXCtrlC
	Gosub,ADDCLIP
    tooltip=Copying to %perm_cur% %lastclip%.clip
	Gosub,TOOLTIP
	Gosub,INDEX
}
Else
{
  tooltip=%perm_cur% - Same selection
  Gosub,TOOLTIP
}
Clipboard:=clipBdPrev
;clipBdPrev=

clip1=
clip2=
Return


; $^+v::
; SHOWEND: NOT NEEDED - USE ^!v TWICE TO FIND END
; If showflag != 1
; {
; 	Send, ^+v
; 	Return
; }

$^v::

If clpblock
{
;LControl & RAlt
	If clpblock
	{
		Sleep, 300
		KeyIsDown := GetKeyState("LCtrl","P") AND GetKeyState("v","P") AND GetKeyState("x","P")
		If KeyIsDown
			GoSub, clseekDirBpA
		Else
			Send, ^v
		Return
	}
	KeyIsDown := GetKeyState("LCtrl","P") AND GetKeyState("v","P") AND GetKeyState("x","P")
	If KeyIsDown
		GoSub, clseekDirBpA
	Else
		Send, ^v
	Return
}
; Chk for Normal Paste, bypassing Clipstep:
ClpBp_Paste := GetKeyState("RCtrl","P") AND GetKeyState("v","P")
If ClpBp_Paste
	Goto, T_BarPaste

;if (perm_cur = "(S)\") and (showflag = 1)

;if perm_cur = (S)\
if (SrchOn = 1) and (showflag = 1)
	Goto, SearchmodeOn
IniRead,perm_cur,%A_ScriptDir%\ClpSrch.ini,clipSettings,perm
If perm_cur=0
    perm_cur=
If perm_cur=ERROR
    perm_cur=
If perm_cur=Perm
    Iniread,Perm_cur,%A_ScriptDir%\ClpSrch.ini,clipSettings,perm_Nom
IfNotExist, %A_ScriptDir%%Perm_cur%
    Perm_cur=\Perm
If perm_cur
{
    StringTrimLeft, Perm_cur, Perm_cur, 1
    perm_cur=%perm_cur%\
}

SearchmodeOn:
;=numofclips=0
;=activeclip=1
Gosub,INDEX
curperm_Ret:
If numofclips<1
{
  tooltip=%perm_cur% - No clip exists
  showflag = %Null_var%
; SplashTextOff 
  Progress, Off
  Gosub,TOOLTIP
  delete=no
  paste=yes
  Return
}
; KeyShft := GetKeyState("RShift","P") AND GetKeyState("LCtrl","P")
If paste<>no
{
	If KeyShft
	  activeclip=0
	Gosub,FINDNEXT
}
;	  Gosub,SHOWEND
KeyShft=
Gosub,SHOWCLIP
delete=no
paste=paste
Return

; #IfWinExist, Clip
$^!v::
; SplashTextOff 
; showflag true indicates ^v (SHOWCLIP) mode, & enables key ^!v 
If Showflag
  Goto, Permswitch
Send, ^!v
Return

Permswitch:
Progress, Off
showflag = %Null_var%
SrchOn=
If perm_cur
  Goto, clear_perm
If perm_cur = (S)\
  Goto, clear_perm

IniWrite,Perm,%A_ScriptDir%\ClpSrch.ini,clipSettings,perm
Iniread,Perm_cur,%A_ScriptDir%\ClpSrch.ini,clipSettings,perm_Nom
; IniRead,perm_cur,%A_ScriptDir%\ClpSrch.ini,clipSettings,perm
IfNotExist, %A_ScriptDir%%Perm_cur%
    Perm_cur = \Perm
IfNotExist, %A_ScriptDir%\Perm
  FileCreateDir, %A_ScriptDir%\Perm
If perm_cur
{
StringTrimLeft, Perm_cur, Perm_cur, 1
    perm_cur=%perm_cur%\
}
IniWrite,Perm,%A_ScriptDir%\ClpSrch.ini,clipSettings,perm
tooltip=Switching to Permanent
Gosub,TOOLTIP
numofclips=0
activeclip=1
Gosub,INDEX
activeclip-=1
If activeclip<1
  activeclip=%numofclips%
Goto, curperm_Ret

clear_perm:
perm_cur = %Null_var%
IniWrite,0,%A_ScriptDir%\ClpSrch.ini,clipSettings,perm
tooltip=Switching to Current
Gosub,TOOLTIP
numofclips=0
activeclip=1
Gosub,INDEX
activeclip-=1
If activeclip<1
  activeclip=%numofclips%
Goto, curperm_Ret
;  Return


; #IfWinExist, Clip
$^!c::
; SplashTextOff 
; showflag true indicates ^v (SHOWCLIP) mode, & enables key ^!v 
Iniread,Perm_Nom,%A_ScriptDir%\ClpSrch.ini,clipSettings,perm_Nom
StringTrimLeft, Perm_Nom, Perm_Nom, 1
IfNotExist, %perm_Nom%
{
	Send, ^!c
	Return
}
perm_Nom=%perm_Nom%\

If perm_cur != Perm\
If perm_cur = %Perm_Nom%
	Perm_Nom = Perm\
If perm_cur != %Perm_Nom%
If Showflag
    Goto, Permcopy
Send, ^!c
Return

Permcopy:
Progress, Off
showflag = %Null_var%

tooltip=Copy to Permanent Dir %Perm_Nom%
Gosub,TOOLTIP

readclip=filearray%activeclip%
readclip:=%readclip%
IfExist,%perm_cur%%readclip%.clip0
	Fext=clip0
IfExist,%perm_cur%%readclip%.clip1
	Fext=clip1
IfExist,%perm_cur%%readclip%.clip
	Fext=clip
Fname=%perm_cur%%readclip%.%Fext%
Loop, 9999
{
; In case file of that name exists in %Perm_Nom%\, rename
    if a_index > 9000
        break  ; Terminate the loop
    IfExist, %Perm_Nom%%a_index%.clip*
        continue
;   MsgBox, 4,, OK to COPY %Fname% as`n%A_ScriptDir%%Perm_Nom%\%a_index%.clip, 10
;	IfMsgBox No
;    	return
	FileCopy, %Fname%, %Perm_Nom%%a_index%.*
	IfExist, %Fname%.C
		FileCopy, %Fname%.C, %Perm_Nom%%a_index%.%Fext%.C

	Sleep, 400
	IfExist, %A_ScriptDir%\%Perm_Nom%%a_index%.*
	{
		SplashTextOn,300,30, Note:, %Fname% copied as`n%Perm_Nom%%a_index%.clip*
		Sleep 2000
		SplashTextOff
;	    MsgBox, 0,, %Fname% copied as`n\Perm\%a_index%.clip, 4
	}
	Break
}
delete=no
paste=no
Return


ADDCLIP:
readclip=filearray1
readclip:=%readclip%
lastclip=%readclip%
numofclips+=1
activeclip=1
AddCLBPa:
lastclip+=1
IfExist,%perm_cur%%lastclip%.clip*
	Goto, AddCLBPa
FileAppend,%ClipboardAll%,%perm_cur%%lastclip%.clip
clipPrev := ClipboardAll
Clipboard:=clipBdPrev
;clipBdPrev=
Return


SHOWCLIPsr:

readclip=filearray%activeclip%
readclip:=%readclip%
IfNotExist,%perm_cur%%readclip%.clip*
{
  clip2=%perm_cur%%readclip%.clip missing
  Return
}
IfExist,%perm_cur%%readclip%.clip0
  FileRead,Clipboard,*c %perm_cur%%readclip%.clip0
IfExist,%perm_cur%%readclip%.clip1
  FileRead,Clipboard,*c %perm_cur%%readclip%.clip1
IfExist,%perm_cur%%readclip%.clip
  FileRead,Clipboard,*c %perm_cur%%readclip%.clip
If cltype <> pending
    Goto, Show_noType

SlType=
IfExist,%perm_cur%%readclip%.clip0
	SlType = 0
IfExist,%perm_cur%%readclip%.clip1
	SlType = 1
Loop, parse, Clipboard, `n, `r
{
    If A_Index >= 2
       break
    If A_Index = 1
	{
	  IfNotInString, A_LoopField, *
	  {
		IfExist, %A_LoopField%
    		cltype = "FILE"
;    	if InStr(FileExist("%A_LoopField%"), "D")
		FileGetAttrib, Attributes, %A_LoopField%
		IfInString, Attributes, D
			cltype = "FOLDER"
		Attributes=
	  }
    }

	; StringLeft,Cur_Ln,Clipboard,12
	StringLeft,Cur_Ln,A_LoopField,12
	If Cur_Ln contains www.,http:,https:,ftp:,://
	{
    	cltype = "ADDR"
	    pos=
	}

    StringGetPos, pos, A_LoopField, @
    if pos >= 0
	{
	  if pos < 32
	  {
		pos += 1
		StringTrimLeft, Cur_Ln, A_LoopField,%pos%
	    StringGetPos, pos, Cur_Ln, .
	    if pos >= 0
		{
			StringLeft, Cur_Ln, Cur_Ln,%pos%
			IfNotInString, Cur_Ln, %A_Space%
				cltype = "ADDR"
			Cur_Ln=
		}		
	  }
    pos=
	}
	Else
		Break		
}

Show_noType:
StringReplace,clip2,Clipboard,%A_Tab%,%A_Space%,All
StringReplace, clip2, clip2,`r`n`r`n,`n, All
;StringReplace, clip2, clip2,`n`r`n,`n, All
StringReplace, clip2, clip2,`n`n`n,`n`n, All
StringReplace, clip2, clip2, `,, , All
If clip2=%A_Space%
  clip2=... Word Image
If clip2=%A_Space%%A_Space%
  clip2=... Word Image
If clip2=
  clip2=... Image

StringLeft,clip2,Clip2,1000
LnCnt := 0
ClipLn =
Cur_Ln =
Loop, parse, Clip2, `n, `r
{
;    If A_Index >= 4
;      break
;  If StrLen(A_LoopField) < 1
;		continue
  If ActiveTitle contains .txt,.txx,.txy
  {
	LnCnt := LnCnt + StrLen(A_LoopField)/80
	If (StrLen(A_LoopField) / 80) < 1
	    LnCnt+=1
	    ClipLn = %ClipLn%%A_Space%%A_LoopField%
;	If ActiveTitle contains .txt,.txx,.txy,.doc
;	Else	
;	    ClipLn = %ClipLn%`n%A_LoopField%
  }
  Else	
  {
	StringLeft,Cur_Ln,A_LoopField,80
	ClipLn = %ClipLn%`n%Cur_Ln%
	LnCnt+=1

;	IfExist, %A_LoopField%
		If cltype contains "FILE","FOLDER","ADDR",pending
	    {
		  Cur_Ln := SubStr(A_LoopField, 81, 78) 
		  ClipLn = %ClipLn%%Cur_Ln%
	      LnCnt+=1
	    }
  }
	If (LnCnt > 6)
		break
}
;        StringLeft,clip2,Clipboard,100

StringTrimLeft, Cur_Ln, ClipLn,1
If ClipLn = `n%Cur_Ln%
	ClipLn = %Cur_Ln%
StringTrimRight Cur_Ln, ClipLn,1
If ClipLn = %Cur_Ln%`n
	ClipLn = %Cur_Ln%
If (LnCnt < 3)
	Clip2 = `n%ClipLn%`n
Else
	Clip2 = %ClipLn%

Return

SHOWCLIP:

clipBdPrev:=ClipboardAll
clip2=%Null_var%
clip3=%Null_var%
Gui, Destroy

If numofclips=1
  Goto, show_no_prev
activeclip-=1
If activeclip<1
  activeclip=%numofclips%
cltype=
GoSub,SHOWCLIPsr
clip3= %A_Tab%%A_Tab%%A_Tab%<-1<%clip2%
activeclip+=1
show_no_prev:
If activeclip>%numofclips%
  activeclip=1
cltype = pending
GoSub,SHOWCLIPsr
readclipS=%readclip%
clip3=%clip3%`n############################################################################ `n%clip2%
;               `n%clip2%
;               `n%clip2%
;              
If numofclips=1
{
  clip2=
  clip3=%clip3%`n############################################################################`n
;                `n
;                `n
  Goto, show_no_next
}
activeclip+=1
If activeclip>%numofclips%
  activeclip=1
If cltype = pending
  cltype=
GoSub,SHOWCLIPsr
clip3=%clip3%`n############################################################################ `n>+1>%clip2%
;               `n>+1>%clip2%
;               `n>+1>%clip2%
; StringReplace, clip3, clip3,`r`n`r`n,`n, All
; StringReplace, clip3, clip3,`n`r`n,`n, All
; StringReplace, clip3, clip3,`n`n,`n, All
; StringReplace, clip2, clip2, `,, , All
activeclip-=1
show_no_next:
If activeclip<1
  activeclip=%numofclips%
If cltype = pending
  cltype=
; ToolTip,Clip %perm_cur% - %activeclip% of %numofclips%`n%clip2% ... 
; Progress, Off
IfWinExist, clpSeek
	Goto,clpseekByps
;SplashTextOn, 450, 80, Clip, %perm_cur% - %activeclip% of %numofclips%`n%clip2% ... 
; WinMove, Clip, , 0, 0 ; Move the splash window to the top left corner. 
; Msgbox, Press OK to dismiss the SplashText
; Progress, m1 b1 fs10 fm10 zh0, %clip2% ..., %perm_cur% - %activeclip% of %numofclips% , Clip, Arial
; Progress, zh0 fs12 X0 Y0 to locate top right
; Progress, m1 b1 Y160 H280 W400 CWE0E0E0 fs10 fm8 zh0, %clip3% ..., %perm_cur%%readclipS%.clip%SlType% - - %activeclip% of %numofclips%  %cltype% , Clip, Arial

;;   Colours - Blue: EEEEF9  or Green: DEEEE9 , Silver: C0C0C0 , Dk Grey: 808080
If ActiveTitle contains .txt,.txx,.txy
	Progress, m1 b1 Y100 H%prg_height% W%prg_width% CWE0E0E0 fs10 fm8 zh0, %clip3% ..., %perm_cur%%readclipS%.clip%SlType% - - %activeclip% of %numofclips%  %cltype% , Clip, Arial
Else
	Progress, m1 b1 Y100 H%prg_height% W%prg_width% CWE0E0E0 C0 fs%Font_SizeT% fm%Font_SizeH% zh0, %clip3% ..., %perm_cur%%readclipS%.clip%SlType% - - %activeclip% of %numofclips%  %cltype% , Clip, Arial
; showflag true indicates ^v (SHOWCLIP) mode, & enables key ^!v 

clpseekByps:
showflag = 1
Clipboard:=clipBdPrev
;clipBdPrev=
clip1=
clip2=
clip3=
cltype=
readclipS=

SetTimer,TOOLTIPOFF,Off

If clpSeekAct = 1
	Sleep, 500
KeyIsDown := GetKeyState("LCtrl","P") AND GetKeyState("v","P") AND GetKeyState("c","P")
If KeyIsDown
	GoSub, clipseekBpA
KeyIsDown := GetKeyState("LCtrl","P") AND GetKeyState("v","P") AND GetKeyState("x","P")
If KeyIsDown
	GoSub, clseekDirBpA

; SetTimer,TOOLTIPOFF,Off
Return

; Enter:
; ButtonOK:
; GuiClose:
; GuiEscape:
Gui, Submit  ; Save each control's contents to its associated variable.
MsgBox You entered:`n%MyEdit%
Gui, Destroy
Return


SHOWCLIP0:
readclip=filearray%activeclip%
readclip:=%readclip%

clipBdPrev:=ClipboardAll
IfExist,%perm_cur%%readclip%.clip0
  FileRead,Clipboard,*c %perm_cur%%readclip%.clip0
IfExist,%perm_cur%%readclip%.clip1
  FileRead,Clipboard,*c %perm_cur%%readclip%.clip1
IfExist,%perm_cur%%readclip%.clip
  FileRead,Clipboard,*c %perm_cur%%readclip%.clip
StringLeft,clip2,Clipboard,100
If clip2=
  clip2=... Image
ToolTip,Clip %perm_cur% - %readclip% of %numofclips%`n%clip2% ... 
SetTimer,TOOLTIPOFF,Off
Clipboard:=clipBdPrev
;clipBdPrev=
clip1=
clip2=
Return
 

PASTECLIP:
clipBdPrev:=ClipboardAll

If TaskBPaste = 1
    Goto, TbarPaste

readclip=filearray%activeclip%
readclip:=%readclip%
Formtyp=

IfExist,%perm_cur%%readclip%.clip0
{
  FileRead,Clipboard,*c %perm_cur%%readclip%.clip0
  IfExist, %perm_cur%%readclip%.clip0.C
  {
	FileRead, ClipCmnt, %perm_cur%%readclip%.clip0.C
	StringCaseSense, Off
	IfInString, ClipCmnt, Form
		Formtyp := 1
  }
}
If Formtyp
	Goto, Pasteform
IfExist,%perm_cur%%readclip%.clip1
  FileRead,Clipboard,*c %perm_cur%%readclip%.clip1
IfExist,%perm_cur%%readclip%.clip
  FileRead,Clipboard,*c %perm_cur%%readclip%.clip

pastetyp=
Loop, parse, Clipboard, `n, `r
{
    If A_Index >= 4
       break
    IfExist, %A_LoopField%
    {
	    pastetyp = %A_LoopField%
    }
}

If pastetyp
   Goto, PasteDel
pastetyp=
Send,^v
Clipboard:=clipBdPrev
showflag = %Null_var%
delete=no
paste=no
Return

Pasteform:
formclip:=clipboard
Loop, parse, formClip, %A_Tab%, `r
{
;    If A_Index >= 4
;       break
    If A_LoopField
	 SendInput, %A_LoopField%%A_Tab%
    Else
	 SendInput, %A_Tab%
}
formclip =
Clipboard:=clipBdPrev
showflag = %Null_var%
delete=no
paste=no
Return

PasteDel:
Send,^v
Sleep 400
showflag = %Null_var%
delete=no
paste=no
IfExist, %pastetyp%
{
	pastetyp=
	Clipboard:=clipBdPrev
	Return
}
;  MsgBox, pastetyp=%pastetyp%, pasteDEL=%pasteDEL%
pastetyp=
Filedelete,%perm_cur%%readclip%.clip*
tooltip=Deleting Clip %perm_cur%%readclip% of %numofclips%
Gosub,TOOLTIP
Gosub,INDEX
Gosub,FINDPREV
Return


TOOLTIPShrt:
NewTooltip = 1
ToolTip,%tooltip%, 600, 200
SetTimer,TOOLTIPOFF,200
Return


TOOLTIP:
NewTooltip = 1
ToolTip,%tooltip%, 600, 200
SetTimer,TOOLTIPOFF,2000
Return


TOOLTIPOFF:
ToolTip,
NewTooltip=

; SplashTextOff 
Progress, Off
showflag = %Null_var%
SetTimer,TOOLTIP,Off
Return


INDEXCtrlC:
filelist=
;Loop,%perm_cur%*.clip*.
Loop,%perm_cur%*.clip
{
;	If A_LoopFileExt = C
;		continue
	StringTrimRight,filename,A_LoopFileName,5
	StringReplace, filename, filename, ., ,
	filelist=%filelist%%filename%`n
}
StringTrimRight,filelist,filelist,1
Sort,filelist,N R
filearray:=0
StringSplit,filearray,filelist,`n
numofclips=%filearray0%
if numofclips=0
	filearray1=0

Return

INDEX:
filelist=
Loop,%perm_cur%*.clip*.
{
;	If A_LoopFileExt = C
;		continue
	StringTrimRight,filename,A_LoopFileName,5
	StringReplace, filename, filename, ., ,
	filelist=%filelist%%filename%`n
}
StringTrimRight,filelist,filelist,1
Sort,filelist,N R
filearray:=0
StringSplit,filearray,filelist,`n
numofclips=%filearray0%
if numofclips=0
	filearray1=0
Return

FINDNEXT:
  If numofclips<1
  {
    tooltip=%perm_cur% - No clip exists
    Gosub,TOOLTIP
    delete=no
    paste=yes
    Return
  }
activeclip+=1
If activeclip>%numofclips%
  activeclip=1
Return


FINDPREV:
  If numofclips<1
  {
    tooltip=%perm_cur% - No clip exists
    Gosub,TOOLTIP
    delete=no
    paste=yes
    Return
  }
activeclip-=1
If activeclip<1
  activeclip=%numofclips%
Return


SrchFor:
; Copy only the source files that contain string
; in the destination:
Progress, Off
showflag = %Null_var%

; perm_cur = Perm\
IfNotExist, Perm
  FileCreateDir, Perm
;IfExist, %perm_cur%(S)
;  FileRemoveDir, %perm_cur%(S) , 1
;IfNotExist, %perm_cur%(S)
;  FileCreateDir, %perm_cur%(S)
;CopyDest = %perm_cur%(S)
; ; perm_cur = %perm_cur%(S)\

;StringReplace, perm_cur, perm_cur, (S)\, , All

IfExist, %A_ScriptDir%\(S)
  FileRemoveDir, %A_ScriptDir%\(S) , 1
IfNotExist, %A_ScriptDir%\(S)
  FileCreateDir, %A_ScriptDir%\(S)
CopyDest = %A_ScriptDir%\(S)
; perm_cur = %perm_cur%(S)\

if Perm_cur = (S)\
	Perm_cur=
StringReplace, perm_cur, perm_cur, (S)\, , All
clip_Prev:=ClipboardAll

IfExist %perm_cur%*.clip0
{
	CopySourcePattern = %perm_cur%*.clip0
	GoSub, CopyIfSel
}
IfExist %perm_cur%*.clip1
{
	CopySourcePattern = %perm_cur%*.clip1
	GoSub, CopyIfSel
}
CopySourcePattern = %perm_cur%*.clip
GoSub, CopyIfSel

spkeys=
Clipboard=
IfNotExist, (S)\*.clip*
{
;    tooltip=%perm_cur% - Search: No files Selected
;    Gosub,TOOLTIP
    MsgBox, 5, , No files Selected, 3
    IfMsgBox Retry
       Goto, ClipSearch
	clipboard = %clip_Prev%
	clip_Prev=
    Return
}
perm_cur = (S)\
numofclips=0
activeclip=1
Gosub,INDEX
; Gosub,SHOWCLIP
delete=no
paste=no
; Next 2 lines to SHOWCLIPs in [CTRLdown] MODE
clipboard = %clip_Prev%
clip_Prev=

SetTitleMatchMode, 2  ; In case it's 3. This setting is in effect only for this thread.
IfWinExist, clpSeek
{
	PostMessage, 0x112, 0xF060,,, clpSeek,  ; 0x112 = WM_SYSCOMMAND, 0xF060 = SC_CLOSE
;	WinClose, clpSeek
	Goto, clipseekBpA
;	run, %A_ScriptDir%\clipseek.exe -clstep
}
Else
{
	Send, {Ctrl Down}
	Goto, curperm_Ret
}
Return


CopyIfSel:
; Caller has set the variables CopySourcePattern and CopyDest for us.

Loop, %CopySourcePattern%
{
    copy_it = n
    FileRead,Clipboard,*c %A_LoopFileName%
    If spkeys = _F_I_L_E
       Goto, filetyp
    If spkeys = _A_D_D_R
       Goto, addrtyp

    Goto, txtString

filetyp:
    Loop, parse, Clipboard, `n, `r
    {
        If A_Index >= 2
           break
        If A_Index = 1
		IfNotInString, A_LoopField, *
	  	{
			IfExist, %A_LoopField%
           		copy_it = y
	  	}
    }
    Goto, Copyit_ifYES

addrtyp:
	StringLeft,Cur_Ln,Clipboard,12
	If Cur_Ln contains www.,http:,https:,ftp:,://
	{
        copy_it = y
	    pos=
	}
    StringGetPos, pos, Clipboard, @
    if pos >= 0
	{
	  if pos < 32
	  {
		pos += 1
		StringTrimLeft, Cur_Ln, Clipboard,%pos%
	    StringGetPos, pos, Cur_Ln, .
	    if pos >= 0
		{
			StringLeft, Cur_Ln, Cur_Ln,%pos%
			IfNotInString, Cur_Ln, %A_Space%
		        copy_it = y
			Cur_Ln=
		}		
	  }
    pos=
	}
    Goto, Copyit_ifYES

txtString:
	copy_itparse=
	StringReplace, Clipboard, Clipboard, //, %A_Space%
	loop, parse, keys, %A_Space%
	{
	    StringGetPos, pos, Clipboard, %A_LoopField%
    	if pos >= 0
      		copy_itparse = %copy_itparse%y
		Else
			copy_itparse = %copy_itparse%n
	}
	pos=
	IfInString, copy_itparse, n
		copy_it = n
	Else
		copy_it = y
	copy_itparse=

Copyit_ifYES:
    if copy_it = y
    {
        FileCopy, %A_LoopFileFullPath%, %CopyDest%\%A_LoopFileName%, 1   ; Copy with overwrite=yes
        if ErrorLevel
            MsgBox, 0, , Could not copy "%A_LoopFileFullPath%" to "%CopyDest%\%A_LoopFileName%", 5
		IfExist %A_LoopFileFullPath%.C
	        FileCopy, %A_LoopFileFullPath%.C, %CopyDest%\%A_LoopFileName%.C, 1
    }
}
Return

INI:
IfNotExist, %A_ScriptDir%\ClpSrch.ini
{
  IniWrite,,%A_ScriptDir%\ClpSrch.ini,Settings,Remvd
  IniWrite,A_StartMenu|A_StartMenuCommon,%A_ScriptDir%\ClpSrch.ini,Settings,scanPath
  IniWrite,G:\V\Q\FreeCMDR\freeCommander.exe,%A_ScriptDir%\ClpSrch.ini,Settings,dirExplorer
  IniWrite,1,%A_ScriptDir%\ClpSrch.ini,Settings,StrtShowAll
  IniWrite, 0,%A_ScriptDir%\ClpSrch.ini,clipSettings,perm
  IniWrite,\Perm,%A_ScriptDir%\ClpSrch.ini,clipSettings,perm_Nom
}
IniRead,keys,%A_ScriptDir%\ClpSrch.ini,Settings,keys
If keys=ERROR
  keys=
Return

If perm_cur
    IniWrite,Perm,%A_ScriptDir%\ClpSrch.ini,clipSettings,perm
Else
    IniWrite, 0,%A_ScriptDir%\ClpSrch.ini,clipSettings,perm

Return



TRAYMENU:
If clpblock
	Goto, clpblkTRAYMENU

; Critical
Menu,Tray,DeleteAll 
Menu,Tray,NoStandard 
Menu,Tray,Add,&About...,ABOUTMAC
Menu,Tray,Add,Clipsearch info,ABOUTSearch
Menu,Tray,Add,Clipstep &Help,CLIPHELP
Menu,Tray,Add,
Menu,Tray,Add,ClipSearch...,ClipSearch
Menu,Tray,Add,ClipSelect...,clipseekBpA
Menu,Tray,Add,ClipSeek Dir,clseekDirBpA
Menu,Tray,Add,
Menu,Tray,Add,Paste ClipBd,T_BarPaste
Menu,Tray,Add,clipBlock On,ClipBlockOn
If SC_A
Menu,Tray,Add,A: %PrgSC_A%,SC_A_ON
If SC_S
Menu,Tray,Add,S: %PrgSC_S%,SC_S_ON
If SC_D
Menu,Tray,Add,D: %PrgSC_D%,SC_D_ON
If SC_F
Menu,Tray,Add,F: %PrgSC_F%,SC_F_ON
Menu,Tray,Add,SC. Define,SC_Define
If (SC_A) OR (SC_S) OR (SC_D) OR (SC_F)
	Menu,Tray,Add,
Menu,Tray,Add,&Pause-Tgl..,PSuspend
Menu,Tray,Add,E&xit,EXIT
Menu,Tray,Default,ClipSearch...
Menu,Tray,Tip,Clipstep
Return

; ^!NumpadMult::
clpblkTRAYMENU:
Menu,Tray,DeleteAll 
Menu,Tray,NoStandard 
;Menu,Tray,Add,&About...,ABOUTMAC
;Menu,Tray,Add,Clipsearch info,ABOUTSearch
Menu,Tray,Add,Clipstep &Help,CLIPHELP
Menu,Tray,Add,
;Menu,Tray,Add,ClipSearch...,ClipSearch
;Menu,Tray,Add,ClipSelect...,clipseekBpA
Menu,Tray,Add,ClipSeek Dir,clseekDirBpA
Menu,Tray,Add,
Menu,Tray,Add,Paste ClipBd,T_BarPaste
Menu,Tray,Add,clipBlock OFF,ClipBlockOff
If SC_A
Menu,Tray,Add,A: %PrgSC_A%,SC_A_ON
If SC_S
Menu,Tray,Add,S: %PrgSC_S%,SC_S_ON
If SC_D
Menu,Tray,Add,D: %PrgSC_D%,SC_D_ON
If SC_F
Menu,Tray,Add,F: %PrgSC_F%,SC_F_ON
Menu,Tray,Add,SC. Define,SC_Define
If (SC_A) OR (SC_S) OR (SC_D) OR (SC_F)
	Menu,Tray,Add,
Menu,Tray,Add,&Pause-Tgl..,PSuspend
Menu,Tray,Add,E&xit,EXIT
Menu,Tray,Default,ClipSeek Dir
Menu,Tray,Tip,Clipseek
Return




clseekDir:
;If showflag = %Null_var%
;	Return
delete=no
paste=no
If showflag
	SetTimer,TOOLTIPOFF,Off

clseekDirBpA:
Gui,Destroy
SrchOn=
GoSub, TOOLTIPOFF
; If showflag = 1
; {
	delete=no
	paste=no
;	Send, {Ctrl Up}
	Progress, Off
	showflag=

	If clpSeekAct = 1
		Return
	SetTitleMatchMode, 2  ; In case it's 3. This setting is in effect only for this thread.
	IfWinExist, clpSeek
		Return
	Else
		If clpblock != 1
			clpSeekAct = 1

;		PostMessage, 0x112, 0xF060,,, clpSeek,  ; 0x112 = WM_SYSCOMMAND, 0xF060 = SC_CLOSE
;		WinClose, clpSeek
    run, %A_ScriptDir%\clipseek.exe -clstDir
	Sleep, 100
; }

Return

SC_A_ON:
If SC_A
	Run, %SC_A%
Return
SC_S_ON:
;clpSeekAct = 1
;SC_S_key=
If SC_S
	Run, %SC_S%
Return
SC_D_ON:
If SC_D
	Run, %SC_D%
Return
SC_F_ON:
If SC_F
	Run, %SC_F%
Return

SC_Define:
FileSelectFile, OutputVar , S35, ::{20d04fe0-3aea-1069-a2d8-08002b30309d}, Select Clipstep SC_Program, Program files (*.exe; *.com; *.bat; *.lnk)
if ErrorLevel
	Return
if OutputVar =
    return
; InputBox, SC_type, Clipstep SC_Program, Program files, Please enter designated Shortcut letter`nSelect from: A`, S`, D`, F`n,,575,
; --------------------------------
CoordMode, ToolTip, Screen
Tooltip,Available Shortcut Letters: `nSelect one of the following MENU SC. letters:`n_____________________________________________`n	A`, S`, D`, or F:`n, 600, 600
Input, UserInput, T120 L1 I, {enter}.{esc}{tab}, A,S,D,F,X
if ErrorLevel = Timeout
{
	MsgBox, 0, , You entered "%UserInput%" the input timed out., 2
	Tooltip
	return
}
if ErrorLevel = NewInput
{
	Tooltip
	return
}
IfInString, ErrorLevel, EndKey:
{
;	MsgBox 0, , You entered "%UserInput%" and terminated W_Mode with %ErrorLevel%., 2
	Tooltip
	return
}
if UserInput = A
	Goto, Mn_SCcreate
else if UserInput = S
	Goto, Mn_SCcreate
else if UserInput = D
	Goto, Mn_SCcreate
else if UserInput = F
	Goto, Mn_SCcreate
Tooltip
Return
Mn_SCcreate:
Tooltip

SC_%UserInput% = %OutputVar%
if UserInput = A
{
	SplitPath, SC_A,,Dir_SC_A,Ext_SC_A,PrgSC_A
	If Ext_SC_A != lnk
	{
		IfExist, %A_ScriptDir%\!filscrpt\%PrgSC_A%.lnk
			FileDelete, %A_ScriptDir%\!filscrpt\%PrgSC_A%.lnk
		FileCreateShortcut, %SC_A%, %A_ScriptDir%\!filscrpt\%PrgSC_A%.lnk
;		, %Dir_SC_A%
		IniWrite,%A_ScriptDir%\!filscrpt\%PrgSC_A%.lnk,%A_ScriptDir%\ClpSrch.ini,Settings,SC_A
		SC_A = %A_ScriptDir%\!filscrpt\%PrgSC_A%.lnk
		Dir_SC_A=
		Ext_SC_A=
	}
	Else
		IniWrite,%PrgSC_A%,%A_ScriptDir%\ClpSrch.ini,Settings,SC_A
;	Menu,Tray,Add,A: %PrgSC_A%,SC_A_ON
	Goto, TRAYMENU
}


if UserInput = S
{
	SplitPath, SC_S,,Dir_SC_S,Ext_SC_S,PrgSC_S
	If Ext_SC_S != lnk
	{
		IfExist, %A_ScriptDir%\!filscrpt\%PrgSC_S%.lnk
			FileDelete, %A_ScriptDir%\!filscrpt\%PrgSC_S%.lnk
		FileCreateShortcut, %SC_S%, %A_ScriptDir%\!filscrpt\%PrgSC_S%.lnk
;		, %Dir_SC_S%
		IniWrite,%A_ScriptDir%\!filscrpt\%PrgSC_S%.lnk,%A_ScriptDir%\ClpSrch.ini,Settings,SC_S
		SC_S = %A_ScriptDir%\!filscrpt\%PrgSC_S%.lnk
		Dir_SC_S=
		Ext_SC_S=
	}
	Else
		IniWrite,%PrgSC_S%,%A_ScriptDir%\ClpSrch.ini,Settings,SC_S
;	Menu,Tray,Add,S: %PrgSC_S%,SC_S_ON
	Goto, TRAYMENU
}
if UserInput = D
{
	SplitPath, SC_D,,Dir_SC_D,Ext_SC_D,PrgSC_D
	If Ext_SC_D != lnk
	{
		IfExist, %A_ScriptDir%\!filscrpt\%PrgSC_D%.lnk
			FileDelete, %A_ScriptDir%\!filscrpt\%PrgSC_D%.lnk
		FileCreateShortcut, %SC_D%, %A_ScriptDir%\!filscrpt\%PrgSC_D%.lnk
;		, %Dir_SC_D%
		IniWrite,%A_ScriptDir%\!filscrpt\%PrgSC_D%.lnk,%A_ScriptDir%\ClpSrch.ini,Settings,SC_D
		SC_D = %A_ScriptDir%\!filscrpt\%PrgSC_D%.lnk
		Dir_SC_D=
		Ext_SC_D=
	}
	Else
		IniWrite,%PrgSC_D%,%A_ScriptDir%\ClpSrch.ini,Settings,SC_D
;	Menu,Tray,Add,D: %PrgSC_D%,SC_D_ON
	Goto, TRAYMENU
}
if UserInput = F
{
	SplitPath, SC_F,,Dir_SC_F,Ext_SC_F,PrgSC_F
	If Ext_SC_F != lnk
	{
		IfExist, %A_ScriptDir%\!filscrpt\%PrgSC_F%.lnk
			FileDelete, %A_ScriptDir%\!filscrpt\%PrgSC_F%.lnk
		FileCreateShortcut, %SC_F%, %A_ScriptDir%\!filscrpt\%PrgSC_F%.lnk
;		, %Dir_SC_F%
		IniWrite,%A_ScriptDir%\!filscrpt\%PrgSC_F%.lnk,%A_ScriptDir%\ClpSrch.ini,Settings,SC_F
		SC_F = %A_ScriptDir%\!filscrpt\%PrgSC_F%.lnk
		Dir_SC_F=
		Ext_SC_F=
	}
	Else
		IniWrite,%PrgSC_F%,%A_ScriptDir%\ClpSrch.ini,Settings,SC_F
;	Menu,Tray,Add,F: %PrgSC_F%,SC_F_ON
	Goto, TRAYMENU
}

Return


clipseek:
;If showflag = %Null_var%
;	Return
delete=no
paste=no
If showflag
	SetTimer,TOOLTIPOFF,Off

clipseekBpA:

Gui,Destroy
;SrchOn=
GoSub, TOOLTIPOFF
IfInString, perm_cur,(S)\
{
;   StringReplace, perm_cur, perm_cur, (S)\, , All
    IniWrite,\(S),%A_ScriptDir%\ClpSrch.ini,clipSettings,perm_Nom
	IniWrite,Perm,%A_ScriptDir%\ClpSrch.ini,clipSettings,perm
	numofclips=0
	activeclip=1
	Gosub,INDEX
}
readclip=filearray%activeclip%
readclip:=%readclip%
IniWrite,%readclip%,%A_ScriptDir%\ClpSrch.ini,clipSettings,readclip
 
; If showflag = 1
; {
	delete=no
	paste=no
	Progress, Off
	showflag=
;	Send, {Ctrl Up}

	If clpSeekAct = 1
		Return
	SetTitleMatchMode, 2  ; In case it's 3. This setting is in effect only for this thread.
;	If SrchOn = %Null_var%					;= TEST
	IfWinExist, clpSeek
		Return
	Else
		If clpblock != 1
			clpSeekAct = 1
;		PostMessage, 0x112, 0xF060,,, clpSeek,  ; 0x112 = WM_SYSCOMMAND, 0xF060 = SC_CLOSE
	;	WinClose, clpSeek
	If SrchOn
	{
		SrchOn=
		Sleep, 400
    }
    run, %A_ScriptDir%\clipseek.exe -clstep
	Sleep, 100
; }

Return

ClipSearch:
Gui,Destroy
Progress, Off
Send, {Ctrl Up}
IniRead,keys,%A_ScriptDir%\ClpSrch.ini,Settings,keys
If keys=ERROR
	keys=
; StringReplace, keys, keys, ButtonOK:, , All

; Gui, +AlwaysOnTop -SysMenu -Caption +Owner GCancel 
; Gui,Add,GroupBox,w400 h70 x20 y400,&Keys
Gui, +AlwaysOnTop -SysMenu +Owner GCancel 
Gui,Add,GroupBox,w400 h70,&Keys
Gui,Add,Button,y+10 w75 GClipSearchOK,&OK
Gui,Add,Button,x+5 w75 GClipSearchCANCEL,&Cancel
Gui,Add,Button,x+5 w75 GClipSearchFILE,&S*FILES*
Gui,Add,Button,x+5 w75 GClipSearchADDR,&S*ADDRS*
Gui,Add,Edit,xm+10 ym+30 w380 vskeys,%keys%
; Gui, +Resize
GuiControl, Focus, ClipSearchOK
; GuiControl, Focus, skeys
Gui,Show, ,ClipSearch Define
Return

ClipSearchFILE:
Gui,Submit
spkeys = _F_I_L_E
SrchOn=1
skeys=
Goto SrchFor
Return

ClipSearchADDR:
Gui,Submit
spkeys = _A_D_D_R
; IniWrite,%keys%,ClpSrch.ini,Settings,keys
SrchOn=1
skeys=
Goto SrchFor
Return



#IfWinActive ClipSearch Define
NumpadEnter::

#IfWinActive ClipSearch Define
Enter::


ClipSearchOK:
Gui,Submit
keys:=skeys
If keys
	IniWrite,%keys%,%A_ScriptDir%\ClpSrch.ini,Settings,keys
Else
{
	IniDelete,%A_ScriptDir%\ClpSrch.ini,Settings,keys
	Return
}
SrchOn=1
skeys=
Goto SrchFor
Return

#IfWinActive ClipSearch Define
Escape::

#IfWinActive ClipSearch Define
^F10::

#IfWinActive ClipSearch Define
F10::
ClipSearchCANCEL:
Gui,Destroy
Send, {Ctrl Up}
SrchOn=
; perm_cur = %perm_cur%(S)\
StringReplace, perm_cur, perm_cur, (S)\, , All

numofclips=0
activeclip=1
Gosub,INDEX
delete=no
paste=no
Return

;  OnClipboardChange: NOT USED
;  ToolTip, data type: %A_EventInfo%

TbarPaste:
TaskBPaste=
if A_ThisMenu = Tray
{
	WinActivate, %ActvWindow%
	WinWait, %ActvWindow%, , 1
;	WinMenuSelectItem, A, , Edit, Paste
}
Send,^v
ActvWindow=
delete=no
paste=no
Return

ClipBlockOn:
; Turn clpBlock off
Send, {Ctrl Up}
clpBlock := 1
clpblock_Tgl := 0
Menu,Tray,DeleteAll
Sleep, 200
Goto, clpblkTRAYMENU
Return
ClipBlockOff:
; Turn clpBlock off
Send, {Ctrl Up}
clpBlock := 0
clpblock_Tgl := 0
Menu,Tray,DeleteAll
Sleep, 200
Goto, TrayMenu
Return


T_BarPaste:
;WinActivate
;sleep, 200
;Send, %clipboard%
;Send, ^v
delete=no
paste=paste
TaskBPaste=1
WinGetTitle, ActvWindow, A
If ClpBp_Paste
{
	Send, {Ctrl Up}
	ClpBp_Paste := 0
}
Return

ABOUTSearch:
Gui,Destroy
Gui,Add,Picture,Icon1,Clipstep.exe
Gui,Font,Bold
Gui,Add,Text,x+10 yp+10,Clipstep Search
Gui,Font
Gui,Add,Text,xm,Right-click Taskbar icon and select "ClipSearch".
Gui,Add,Text,xm+10,or Double=click the taskbar icon
Gui,Add,Text,xm,Enter a single unquoted string to search within 
Gui,Add,Text,xm+10,stored clips, using A-Z,1-9, BUT NO COMMAS.
Gui,Add,Text,xm,To change the keys, choose ClipSearch in the tray menu.
Gui,Add,Text,xm+10,If search successful, Clips are shown in [CTRLdown] mode
Gui,Add,Text,xm,To view full selection after Search, Press Alt-Ctrl-V
Gui,Add,Text,xm+10,or select "ClipSearch", and press "Cancel".
Gui,Add,Text,xm,On "Copy" (^C) or "Paste" (^V), full selection is restored
Gui,Add,Text,xm,"ClipSearch" operates on both normal and Perm. selection.
Gui,Add,Text,xm y+15,Made using AutoHotkey - 
Gui,Font,CBlue Underline
Gui,Add,Text,x+5 GAUTOHOTKEY,http://www.autohotkey.com
Gui,Font
Gui,Add,Text,xm,`t
Gui,Add,Picture,Icon2,Cliptep.exe
Gui,Font,Bold
Gui,Add,Text,x+10 yp+10,1 Hour Software by Skrommel
Gui,Font
Gui,Add,Text,xm,For more tools and information, please stop by at
Gui,Font,CBlue Underline
Gui,Add,Text,xm GWWW,http://www.donationcoders.com/skrommel
Gui,Font
Gui,Add,Button,GABOUTOK Default xm+220 y+20 w75,&OK
Gui,Show,,ClipSearch About
about=
Return

ABOUTMAC:
  pn_scriptDir := StrLen(A_ScriptDir) - 40
  If pn_scriptDir > 1
  {
	StringTrimRight, ScriptDirSz, A_ScriptDir, %pn_scriptDir%
	A_ScriptDirSz = %ScriptDirSz%...\
  }
  Else
	ScriptDirSz = %A_ScriptDir%\

Gui,Destroy
Gui,Add,Picture,Icon1,Clipstep.exe
Gui,Font,Bold
Gui,Add,Text,x+10 yp+1,Clipstep v1.1
Gui,Add,Text,xp+1 yp+20,%ScriptDirSz%
Gui,Font
Gui,Add,Text,xm,Control multiple clipboards using only the keyboard's 
Gui,Add,Text,xm+18,Ctrl-X-C-V. 
Gui,Add,Text,xm,Select some text, press Ctrl-C a couple of times to copy
Gui,Add,Text,xm,it to multiple new clipboards. Hold down [Ctrl]
Gui,Add,Text,xm,and press V repeatedly to step through the clipstep clips,
Gui,Add,Text,xm,C steps backwards. When you've got the clipstep clip you want,
Gui,Add,Text,xm,release Ctrl to paste. To delete a clip file, hold down
Gui,Add,Text,xm,[Ctrl], press V followed by X twice to delete, three times
Gui,Add,Text,xm,to delete all, or once to cancel. Release [Ctrl] to accept.
Gui,Add,Text,xm,While [Ctrl] is held, and after "V" is pressed for SHOWCLIPS:
Gui,Add,Text,xm,Press [Ctrl]-Alt-V:  Toggle Current / Permanent dir: .\Perm, OR
Gui,Add,Text,xm,Press [Ctrl]-Alt-C:  COPY current clip TO: Permanent dir., OR
Gui,Add,Text,xm,Press [Ctrl]-V-C:    run the ClipSeek Clip program
Gui,Add,Text,xm,Press [Ctrl]-V-X:    run the ClipSeek Directory Search program
Gui,Add,Text,xm,Press [RightCtrl]-V, -C, or -X:  Normal Paste,Copy,Cut (ClipBoard)
Gui,Add,Text,xm,Press [LeftCtrl]-[RightAlt]-C:   Toggle Clip functions (clpBlock)
Gui,Add,Text,xm,Press [AltGr]-C:                      Toggle Clip functions (clpBlock)
Gui,Add,Text,xm y+15,Made using AutoHotkey - 
Gui,Font,CBlue Underline
Gui,Add,Text,x+5 GAUTOHOTKEY,http://www.autohotkey.com
Gui,Font
Gui,Add,Button,GABOUTOK Default xm+220 y+20 w75,&OK
Gui,Show,,Clipstep About
about=
Return

CLIPHELP:

IfExist %A_ScriptDir%\!filscrpt\clipseek.txt
	Run, %A_ScriptDir%\!filscrpt\clipseek.txt
Return

AUTOHOTKEY:
Run,http://www.autohotkey.com,,UseErrorLevel
Return

WWW:
Run,http://www.donationcoders.com/skrommel,,UseErrorLevel
Return

ABOUTOK:
Gui,Destroy
Return

PSuspend:
Suspend             ; Assign the toggle-suspend function to a hotkey
Return

EXIT:
ExitApp
